@@ -1,6 +1,7 @@
 import random
 import numpy as np
 from diamond.data_augmentation.augmentation import ImageAugmentation
+from diamond.face_detection.face_image_ import ImageFaceDetection
 from diamond.image_caption.image_caption_class import ImageDescription
 from diamond.image_data_info.image_info import ImageInfo
 from diamond.image_object_detection.image_object_class import ImageObjectDetection
@@ -19,6 +20,7 @@ def run(images,
         validation_prop=0.3,
         get_image_description=False, image_description_spec: ImageDescriptionSpec = None,
         get_object_detection=False,
+        detect_faces=False,
         is_augment_data=True, image_augmentation_info=None,
         is_train_model=True, image_models=None,
         is_post_model_analysis=True, image_post_model: ImagePostModelSpec = None,
@@ -26,7 +28,7 @@ def run(images,
         ):
     # Tell a story
     story = """Welcome to MadCat, the comprehensive machine learning and data analysis solution!
-    \nThis module is designed to streamline the entire process image classification models, 
+    \nThis module is designed to streamline the entire process of video tasks,
     \nfrom start to finish.
     \nTo learn more about MadCat, visit https://github.com/amito-ds/chester.\n"""
     print(story)
@@ -36,6 +38,7 @@ def run(images,
         is_train_model = False
         labels = pd.Series([1] * len(images))
     # Image data
+    # TODO: convert in case you got a list of images!
     if type(images).__name__ == "DataFrame":
         images = images.values
 
@@ -49,8 +52,8 @@ def run(images,
     diamond_collector["image_data"] = image_data
     # plot
     if plot:
-        print("Sample Plot")
-        image_data.plot_images()
+        print("Plotting Sample of Images")
+        image_data.plot_images(plot_sample=plot_sample)
 
     # Image description
     if get_image_description:
@@ -62,7 +65,7 @@ def run(images,
             image_description_spec=image_description_spec,
             diamond_collector=diamond_collector,
             plot=plot).run()
-
+    # Object detection
     if get_object_detection:
         print("====> Detecting Objects in the Images")
         ImageObjectDetection(
@@ -71,6 +74,15 @@ def run(images,
             plot_sample=plot_sample,
             plot=plot).run()
 
+    # Face detection
+    if detect_faces:
+        print("====> Detecting Faces in the Images")
+        ImageFaceDetection(
+            images_data=image_data,
+            diamond_collector=diamond_collector,
+            plot_sample=plot_sample,
+            plot=plot).run()
+
     # augmentation
     if is_augment_data:
         print("====> Augmenting data")
@@ -80,8 +92,8 @@ def run(images,
         diamond_collector["augmented_image_data"] = image_data
         # plot
         if plot:
-            print("Updated Sample Plot")
-            image_data.plot_images()
+            print("Updated Plotting Sample of Images")
+            image_data.plot_images(plot_sample=plot_sample)
 
     # Training
     if not is_train_model:
